<?php
/**
* 2015 Skrill
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
*  @author    Skrill <contact@skrill.com>
*  @copyright 2015 Skrill
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of Skrill
*/

use PrestaShop\PrestaShop\Core\Payment\PaymentOption;

if (!defined('_PS_VERSION_')) {
    exit;
}

class Paykeeper extends PaymentModule
{
    protected $config_form = false;

    public function __construct()
    {
        $this->name = 'paykeeper';
        $this->tab = 'payments_gateways';
        $this->version = '2.0.0';
        $this->ps_versions_compliancy = array('min' => '1.7', 'max' => _PS_VERSION_);
        $this->author = 'PayKeeper';
        $this->controllers = array('payment');
        $this->need_instance = 0;

        $this->currencies = true;
        $this->currencies_mode = 'checkbox';

        $this->bootstrap = true;
        parent::__construct();

        $this->displayName = $this->trans('PayKeeper', array(), 'Modules.Paykeeper.Admin');
        $this->description = $this->trans('Оплата через платежную платформу PayKeeper.', array(), 'Modules.Paykeeper.Admin');
        //$this->displayName = 'PayKeeper';
        //$this->description = 'Accepts payments by PayKeeper';
    }

    public function install()
    {
       $this->warning = null;
    //order reqeust
    //    if (is_null($this->warning) && !function_exists('curl_init')) {
    //        if ($this->l('ERROR_MESSAGE_CURL_REQUIRED') == "ERROR_MESSAGE_CURL_REQUIRED") {
    //            $this->warning = "cURL is required to use this module. Please install the php extention cURL.";
    //        } else {
    //            $this->warning = $this->l('ERROR_MESSAGE_CURL_REQUIRED');
    //        }
    //    }
        if (is_null($this->warning)
            && !(parent::install()
            && $this->registerHook('paymentReturn')
            //order request
            //&& $this->registerHook('displayPayment')
            && $this->registerHook('displayPaymentReturn')
            && $this->registerHook('paymentOptions'))) {
            if ($this->l('ERROR_MESSAGE_INSTALL_MODULE') == "ERROR_MESSAGE_INSTALL_MODULE") {
                $this->warning = "There was an Error installing the module.";
            } else {
                $this->warning = $this->l('ERROR_MESSAGE_INSTALL_MODULE');
            }
        }
        else return is_null($this->warning);
    }

    public function uninstall()
    {
        if (!Configuration::deleteByName('PAYKEEPER_URL')
            || !Configuration::deleteByName('PAYKEEPER_SECRET')
            || !parent::uninstall()) {
                return false;
        }
        return true;
    }

    /**
     * Load the configuration form
     */
    public function getContent()
    {
        /**
         * If values have been submitted in the form, process.
         */
        if (((bool)Tools::isSubmit('submitPaykeeperModule')) == true) {
            $this->postProcess();
        }

        return $this->renderForm();
    }

    /**
     * Create the form that will be displayed in the configuration of your module.
     */
    protected function renderForm()
    {
        $helper = new HelperForm();

        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $helper->module = $this;
        $helper->default_form_language = $this->context->language->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG', 0);

        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submitPaykeeperModule';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false)
            .'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');

        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFormValues(), /* Add values for your inputs */
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
        );

        return $helper->generateForm(array($this->getConfigForm()));
    }

    /**
     * Create the structure of your form.
     */
    protected function getConfigForm()
    {
        return array(
            'form' => array(
                'legend' => array(
                'title' => $this->l('Settings'),
                'icon' => 'icon-cogs',
                ),
                'input' => array(
                    array(
                        'type' => 'text',
                        'name' => 'PAYKEEPER_URL',
                        'label' => $this->l('URL формы'),
                    ),
                    array(
                        'type' => 'text',
                        'name' => 'PAYKEEPER_SECRET',
                        'label' => $this->l('Секретный ключ'),
                    ),
                ),
                'submit' => array(
                    'title' => $this->l('Save'),
                ),
            ),
        );
    }

    /**
     * Set values for the inputs.
     */
    protected function getConfigFormValues()
    {
        return array(            
            'PAYKEEPER_URL' => Configuration::get('PAYKEEPER_URL', null),
            'PAYKEEPER_SECRET' => Configuration::get('PAYKEEPER_SECRET', null),
        );
    }

    /**
     * Save form data.
     */
    protected function postProcess()
    {
        $form_values = $this->getConfigFormValues();

        foreach (array_keys($form_values) as $key) {
            Configuration::updateValue($key, Tools::getValue($key));
        }
    }

    public function hookPaymentOptions($parameters)
    {
        if (!$this->active) {
                    return;
        }

        //if (!$this->checkCurrency($parameters['cart'])) {
            //return;
        //}

//        $this->smarty->assign(
//            $this->getTemplateVars()
//        );

        $newOption = new PaymentOption();
        $paymentOptions = array();

        $newOption->setModuleName($this->name)
                ->setCallToActionText($this->trans('Оплата картами Visa и MasterCard на сайте', array(), 'Modules.Paykeeper.Admin'))
                ->setAction($this->context->link->getModuleLink($this->name, 'payment', array(), true))
                ->setAdditionalInformation($this->fetch('module:paykeeper/views/templates/front/payment_info.tpl'));

        $paymentOptions[] = $newOption;

        return $paymentOptions;
    }

    public function hookPaymentReturn($parameters)
    {
        if (!$this->active) {
            return;
        }

        echo "Thank you fro you order!";
    }

    public function getTemplateVars() {
        return;
    }
}
